#!/bin/bash

SOURCE="${BASH_SOURCE[0]}"
while [ -h "$SOURCE" ]; do # resolve $SOURCE until the file is no longer a symlink
  DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"
  SOURCE="$(readlink "$SOURCE")"
  [[ $SOURCE != /* ]] && SOURCE="$DIR/$SOURCE" # if $SOURCE was a relative symlink, we need to resolve it relative to the path where the symlink file was located
done
DIR="$( cd -P "$( dirname "$SOURCE" )" && pwd )"

echo 'Retrieving certificate tarball...'
if hash wget 2>/dev/null; then
  echo 'Wget found...'
  wget https://dist.eugridpma.info/distribution/igtf/current/accredited/igtf-preinstalled-bundle-classic.tar.gz -P $DIR/
elif hash curl 2>/dev/null; then
  echo 'Curl found...'
  curl https://dist.eugridpma.info/distribution/igtf/current/accredited/igtf-preinstalled-bundle-classic.tar.gz > $DIR/certificates.tar.gz
else
  echo 'Neither wget nor curl found! Exit now.' 
  exit 1
fi

echo 'Removing old certificates...'
rm -rf $DIR/voms-clients/etc/certificates
mkdir $DIR/voms-clients/etc/certificates

for a in `ls -1 $DIR/*.tar.gz`; do echo 'Extracting new certificates...'; tar -zxf $a -C $DIR/voms-clients/etc/certificates; done
rm $DIR/*.tar.gz
echo 'Done!'
